//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by ICC_Creator.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDD_ABOUTBOX                    100
#define IDS_ABOUTBOX                    101
#define IDD_ICC_CREATOR_DIALOG          102
#define IDR_MAINFRAME                   128
#define GSIMAGE_ICON                    131
#define GSIMAGE_ICON1                   132
#define IDC_CIELAB                      1000
#define IDC_NAMES                       1001
#define IDC_ICC_PROFILE                 1002
#define IDC_ICC_HELP                    1003
#define IDC_STATUS                      1004
#define IDC_CMYK2RGB                    1005
#define IDC_GRAY2CMYK                   1006
#define IDC_RGB2CMYK                    1007
#define IDC_CMYK2GRAY2                  1008
#define IDC_GRAY2CMYK2                  1009
#define IDC_PSICC                       1009
#define IDC_GRAYTHRESH                  1010
#define IDC_EDITTHRESH                  1011
#define IDC_RGBTHRESH                   1012
#define IDC_EFFECTICC3                  1012
#define IDC_EDITTHRESH2                 1013
#define IDC_EDITTHRESHRGB               1013
#define IDC_GRAYTHRESH2                 1013
#define IDC_CMYKTHRESHINPUT             1013
#define IDC_PSICC2                      1014
#define IDC_PSTABLES                    1014
#define IDC_CHECK1                      1015
#define IDC_EFFECTTABLES2               1016
#define IDC_EDIT1                       1017
#define IDC_EDITTHRESHINPUT             1018
#define IDC_RGBTHRESHINPUT              1019
#define IDC_GRAYTHRESHINPUT             1020

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        132
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1018
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
